@@ -85,7 +85,7 @@ class ReplyProcessor(object):
 
 
 def parseCommand(*argv):
-    output = [["*",str(len(argv)),"\r\n"]] + [["$",str(len(p)),"\r\n",p,"\r\n"] for p in map(str,argv)] + [["\r\n",""]]
+    output = [["*",str(len(argv)),"\r\n"]] + [["$",str(len(p)),"\r\n",p,"\r\n"] for p in map(str,argv)]
     return "".join(reduce(lambda i1,i2:i1+i2 ,output))
 
 class Subscriber(object):
